@@ -84,7 +84,8 @@ is.count <- function(x) {
   if (length(x) != 1) return(FALSE)
   if (!is.integerish(x)) return(FALSE)
   
-  x > 0
+  # is.na() to handle NA_integer_
+  x > 0 && !is.na(x)
 }
 on_failure(is.count) <- function(call, env) {
   paste0(deparse(call$x), " is not a count (a single positive integer)")
