@@ -2,7 +2,9 @@
 NULL
 
 is.integerish <- function(x) {
-  is.integer(x) || (is.numeric(x) && all(x == as.integer(x)))
+  # using trunc() to deal with very large numbers (including Inf) and is.na() to deal with NaN and NA_real_
+  res <- is.integer(x) || (is.numeric(x) && all(x == trunc(x)) && !is.na(x))
+  res
 }
 
 # is.positive.integer
@@ -30,6 +32,7 @@ on_failure(is.named) <- function(call, env) {
 #'
 #' y <- list(a = 1, b = 2)
 #' see_if(y %has_name% "c")
+#' see_if(y %has_name% c("a", "g", "f"))
 has_attr <- function(x, which) !is.null(attr(x, which, exact = TRUE))
 on_failure(has_attr) <- function(call, env) {
   paste0(deparse(call$x), " does not have attribute ", eval(call$which, env))
@@ -40,9 +43,12 @@ on_failure(has_attr) <- function(call, env) {
 
 #' @export
 #' @rdname has_attr
-has_name <- function(x, which) which %in% names(x)
+has_name <- function(x, which){
+    all(which %in% names(x))
+}
 on_failure(has_name) <- function(call, env) {
-  paste0(deparse(call$x), " does not have name ", eval(call$which, env))
+    out_names <- paste0("'", paste0(eval(call$which, env), collapse = "', '"), "'")
+    paste0(deparse(call$x), " does not have all of these name(s): ", out_names)
 }
 #' @export
 #' @rdname has_attr
@@ -136,7 +142,7 @@ on_failure(is.date) <- function(call, env) {
 #' see_if(mean %has_args% "y")
 has_args <- function(f, args, exact = FALSE) {
   assert_that(is.function(f))
-  
+
   if (exact) {
     identical(args, names(formals(f)))
   } else {
